      program savgedge
c
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
c  *              P R O G R A N :  S A V G E D G E                   *
c  *                                                                 *
c  *               (S) TRESS    (AV) ERA  (G)  E                     *
c  *                at the stress free-EDGE of                       *
c  *                TYPE-I and TYPE-II LAMINATES                     *
c  *                                                                 *
c  *     CALCULATES AVERAGE STRESSES ALONG A SET OF ELEMENTS THRU    *
c  *     LAMINATE THICKNESS FROM THE TOP SURFACE TO THE MIDPLANE     *
c  *     FOR ALL SIX COMPONENTS OF THE STRESS TENSOR:                *
c  *                                                                 *
c  *     SIGMA-N, SIGMA-H, SIGMA-Z, SIGMA-HZ, SIGMA-NZ, SIGMA-NH     *
c  *                                                                 * 
c  *     NEAR THE STRESS-FREE-EDGE AT H/B=0.998                      * 
c  *            FROM THE TOP SURFACE (Y/T=1.0)                       *
c  *                 TO THE MIDPLANE (Y/T=0.0)                       *
c  *                                                                 *
c  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
C
      common snm(768),shm(768),szm(768),shzm(768),snzm(768),snhm(768)
      common snt(768),sht(768),szt(768),shzt(768),snzt(768),snht(768)
      common snw(768),shw(768),szw(768),shzw(768),snzw(768),snhw(768)
      common z(64)
      common san(3,64),sah(3,64),saz(3,64),
     *       sahz(3,64),sanz(3,64),sanh(3,64)
C 
C      ASSIGN TAPE NO.S 1,2,3,4/5,6,7,8,9,10 TO INPUT/OUTPUT FILES
C
      OPEN(1,FILE='lfemie_mechstress.out',STATUS='OLD',ERR=8888)
      OPEN(2,FILE='lfemie_thermstress.out',STATUS='OLD',ERR=8888)
      OPEN(3,FILE='lfemie_moiststress.out',STATUS='OLD',ERR=8888)
      OPEN(4,FILE='savgedge_stress_avg.out',STATUS='UNKNOWN',ERR=8888)
      OPEN(5,FILE='dataedge1.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(6,FILE='dataedge2.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(7,FILE='dataedge3.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(8,FILE='dataedge4.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(9,FILE='dataedge5.dat',STATUS='UNKNOWN',ERR=8888)
      OPEN(10,FILE='dataedge6.dat',STATUS='UNKNOWN',ERR=8888)
c
      n=17
      thick=0.02
      ielem=768
c
      do 9 i=1,ielem
      read(1,10)snm(i),shm(i),szm(i),shzm(i),snzm(i),snhm(i)
      read(2,10)snt(i),sht(i),szt(i),shzt(i),snzt(i),snht(i)
    9 read(3,10)snw(i),shw(i),szw(i),shzw(i),snzw(i),snhw(i)
   10 format(5x,6(1x,e12.5))
c
c       CALCULATING POINTS ALONG THE NONDIMENSIONAL Z/T COORDINATES
c
      a=thick/32.0
      b=a*1.0/3.0
      c=a*2.0/3.0
      do 35 i=1,32
      z(2*i-1)=(b+a*(i-1))*50
      z(2*i)=(c+a*(i-1))*50
   35 continue 
c
c   Average SIGMA-N  SIGMA-H  SIGMA-Z 
c           SIGMA-HZ SIGMA-NZ SIGMA-NH stresses 
c   thru all four grid layers along the z-axis at H/B=0.988 
c                           from the top surface (Z/T=1.0) 
c                                to the midplane (Z/T=0.0)
c     MECH STRESSES
      n1=672
      n2=704
      n3=736
      do 36 i=1,32
      san(1,2*i-1) =(snm(i+n1)+snm(i+n2))/2.0
      sah(1,2*i-1) =(shm(i+n1)+shm(i+n2))/2.0
      saz(1,2*i-1) =(szm(i+n1)+szm(i+n2))/2.0
      san(1,2*i)   =(snm(i+n1)+snm(i+n3))/2.0
      sah(1,2*i)   =(shm(i+n1)+shm(i+n3))/2.0
      saz(1,2*i)   =(szm(i+n1)+szm(i+n3))/2.0
      sahz(1,2*i-1)=(shzm(i+n1)+shzm(i+n2))/2.0
      sanz(1,2*i-1)=(snzm(i+n1)+snzm(i+n2))/2.0
      sanh(1,2*i-1)=(snhm(i+n1)+snhm(i+n2))/2.0
      sahz(1,2*i)  =(shzm(i+n1)+shzm(i+n3))/2.0
      sanz(1,2*i)  =(snzm(i+n1)+snzm(i+n3))/2.0
      sanh(1,2*i)  =(snhm(i+n1)+snhm(i+n3))/2.0
   36 continue

c
c     MECH+THERM STRESSES
      do 37 i=1,32
      san(2,2*i-1) =san(1,2*i-1) + (snt(i+n1)+snt(i+n2))/2.0
      sah(2,2*i-1) =sah(1,2*i-1) + (sht(i+n1)+sht(i+n2))/2.0
      saz(2,2*i-1) =saz(1,2*i-1) + (szt(i+n1)+szt(i+n2))/2.0
      san(2,2*i)   =san(1,2*i)   + (snt(i+n1)+snt(i+n3))/2.0
      sah(2,2*i)   =sah(1,2*i)   + (sht(i+n1)+sht(i+n3))/2.0
      saz(2,2*i)   =saz(1,2*i)   + (szt(i+n1)+szt(i+n3))/2.0
      sahz(2,2*i-1)=sahz(1,2*i-1)+ (shzt(i+n1)+shzt(i+n2))/2.0
      sanz(2,2*i-1)=sanz(1,2*i-1)+ (snzt(i+n1)+snzt(i+n2))/2.0
      sanh(2,2*i-1)=sanh(1,2*i-1)+ (snht(i+n1)+snht(i+n2))/2.0
      sahz(2,2*i)  =sahz(1,2*i)  + (shzt(i+n1)+shzt(i+n3))/2.0
      sanz(2,2*i)  =sanz(1,2*i)  + (snzt(i+n1)+snzt(i+n3))/2.0
      sanh(2,2*i)  =sanh(1,2*i)  + (snht(i+n1)+snht(i+n3))/2.0
   37 continue
c
c       MECH+THERM+MOIST STRESSES
c
      do 38 i=1,32
      san(3,2*i-1) =san(2,2*i-1) + (snw(i+n1)+snw(i+n2))/2.0
      sah(3,2*i-1) =sah(2,2*i-1) + (shw(i+n1)+shw(i+n2))/2.0
      saz(3,2*i-1) =saz(2,2*i-1) + (szw(i+n1)+szw(i+n2))/2.0
      san(3,2*i)   =san(2,2*i)   + (snw(i+n1)+snw(i+n3))/2.0
      sah(3,2*i)   =sah(2,2*i)   + (shw(i+n1)+shw(i+n3))/2.0
      saz(3,2*i)   =saz(2,2*i)   + (szw(i+n1)+szw(i+n3))/2.0
      sahz(3,2*i-1)=sahz(2,2*i-1)+ (shzw(i+n1)+shzw(i+n2))/2.0
      sanz(3,2*i-1)=sanz(2,2*i-1)+ (snzw(i+n1)+snzw(i+n2))/2.0
      sanh(3,2*i-1)=sanh(2,2*i-1)+ (snhw(i+n1)+snhw(i+n2))/2.0
      sahz(3,2*i)  =sahz(2,2*i)  + (shzw(i+n1)+shzw(i+n3))/2.0
      sanz(3,2*i)  =sanz(2,2*i)  + (snzw(i+n1)+snzw(i+n3))/2.0
      sanh(3,2*i)  =sanh(2,2*i)  + (snhw(i+n1)+snhw(i+n3))/2.0
   38 continue
c
c       Write SIGMA-H results to a file for plotting
c
      WRITE(4,230)
  230 FORMAT(/,1X,'SIGMA-N STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 231 i=1,64
      WRITE(5,215)z(i),san(1,i),san(2,i),san(3,i)
  231 WRITE(4,215)z(i),san(1,i),san(2,i),san(3,i)
  215 FORMAT(5(1X,E11.4))
c
c--------------------------------------------------------------------
c       Write SIGMA-H results to a file for plotting
c
      WRITE(4,330)
  330 FORMAT(/,1X,'SIGMA-H STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 331 i=1,64
      WRITE(6,215)z(i),sah(1,i),sah(2,i),sah(3,i)
  331 WRITE(4,215)z(i),sah(1,i),sah(2,i),sah(3,i)
c
c--------------------------------------------------------------------
c       Write SIGMA-Z results to a file for plotting
c
      WRITE(4,430)
  430 FORMAT(/,1X,'SIGMA-Z STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 431 i=1,64
      WRITE(7,215)z(i),saz(1,i),saz(2,i),saz(3,i)
  431 WRITE(4,215)z(i),saz(1,i),saz(2,i),saz(3,i)
c
c---------------------------------------------------------------------
c       Write SIGMA-HZ results to a file for plotting
c
      WRITE(4,530)
  530 FORMAT(/,1X,'SIGMA-HZ STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 531 i=1,64
      WRITE(8,215)z(i),sahz(1,i),sahz(2,i),sahz(3,i)
  531 WRITE(4,215)z(i),sahz(1,i),sahz(2,i),sahz(3,i)
c
c----------------------------------------------------------------------
c       Write SIGMA-NZ results to a file for plotting
c
      WRITE(4,630)
  630 FORMAT(/,1X,'SIGMA-NZ STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 631 i=1,64
      WRITE(9,215)z(i),sanz(1,i),sanz(2,i),sanz(3,i)
  631 WRITE(4,215)z(i),sanz(1,i),sanz(2,i),sanz(3,i)
c
c----------------------------------------------------------------------
c       Write SIGMA-NH results to a file for plotting
c
      WRITE(4,730)
  730 FORMAT(/,1X,'SIGMA-NH STRESS DISTR. THRU THE 0 DEG PLY AT H=0'
     *,/,' Z/T POSITION    MECH    MECH+THERM  MECH+THERM+MOIST')
      do 731 i=1,64
      WRITE(10,215)z(i),sanh(1,i),sanh(2,i),sanh(3,i)
  731 WRITE(4,215)z(i),sanh(1,i),sanh(2,i),sanh(3,i)
c
 8888 STOP
      END
